==> flutter_mylibrary-0.4.78.tar.gz: lib/base/base_request_model_controller.dart <==
import 'package:flutter/cupertino.dart';
import 'package:flutter_mylibrary/base/base_view_state.dart';
import 'package:flutter_mylibrary/config/const.dart';
import 'package:flutter_mylibrary/http/http_data.dart';
import 'package:flutter_mylibrary/utils/utils.dart';
import 'package:flutter_mylibrary/widget/widget_template.dart';
import '../flutter_mylibrary.dart';
import 'base_controller.dart';

mixin BaseRequestModelController<T> implements BaseController{

  T data;


  void getData(){
    request((httpData) {
      var data = httpData.data;
      this.data = getRequestInfo()?.handleRes(data);
      onCompleted(this.data);
      setIdle();
      refreshController.finishRefresh();
    });
  }

  onCompleted(T data) {}

  ///获取一个公共的刷新控件
  Widget getEasyRefreshWidget({Widget emptyWidget, ViewStateModelWidgetBuilder<T> builder, Widget busyWidget, bool showErrorWidget = true, bool showEmptyWidget = true, bool showBusyWidget = true, OnLoadCallback onLoad}){
    Widget emptyErrorWidget = buildRefreshNoDataWidget(viewState: this, busyWidget: busyWidget, emptyDataWidget: emptyWidget, showErrorWidget: showErrorWidget, showEmptyWidget: showEmptyWidget, showBusyWidget: showBusyWidget);
    return EasyRefresh(
      emptyWidget: emptyErrorWidget,
      child: isEmpty(emptyErrorWidget)? builder(data) : Container(),
      onRefresh: isBusy? null : () async{
        getData();
      },
      onLoad: onLoad,
      controller: refreshController,
    );
  }


  void requestWhenError(){
    setBusy();
    getData();
  }
}

==> flutter_mylibrary-0.5.1.tar.gz: lib/base/base_request_model_controller.dart <==
import 'package:flutter/cupertino.dart';
import 'package:flutter_mylibrary/config/const.dart';
import 'package:flutter_mylibrary/utils/utils.dart';
import 'package:flutter_mylibrary/widget/widget_template.dart';
import '../flutter_mylibrary.dart';
import 'base_view_state.dart';

mixin BaseRequestModelController<T> on BaseViewState{

  T data;


  void getData(){
    request((httpData) {
      this.data = httpData.data;
      onCompleted(this.data);
      setIdle();
      refreshController.finishRefresh();
    });
  }

  onCompleted(T data) {}

  ///获取一个公共的刷新控件
  Widget getEasyRefreshWidget({Widget emptyWidget, ViewStateModelWidgetBuilder<T> builder, Widget busyWidget, bool showErrorWidget = true, bool showEmptyWidget = true, bool showBusyWidget = true, OnLoadCallback onLoad}){
    Widget emptyErrorWidget = buildRefreshNoDataWidget(viewState: this, busyWidget: busyWidget, emptyDataWidget: emptyWidget, showErrorWidget: showErrorWidget, showEmptyWidget: showEmptyWidget, showBusyWidget: showBusyWidget);
    return EasyRefresh(
      emptyWidget: emptyErrorWidget,
      child: isEmpty(emptyErrorWidget)? builder(data) : Container(),
      onRefresh: isBusy? null : () async{
        getData();
      },
      onLoad: onLoad,
      controller: refreshController,
    );
  }




  Widget getCustomEasyRefreshWidget({Widget emptyWidget, ViewStateModelWidgetListBuilder<T> widgetListBuilder, ViewStateModelWidgetBuilder<T> builder, Widget busyWidget, bool showErrorWidget = true, bool showEmptyWidget = true, bool showBusyWidget = true, OnLoadCallback onLoad}){
    Widget emptyErrorWidget = buildRefreshNoDataWidget(viewState: this, busyWidget: busyWidget, emptyDataWidget: emptyWidget, showErrorWidget: showErrorWidget, showEmptyWidget: showEmptyWidget, showBusyWidget: showBusyWidget);
    return EasyRefresh.custom(
      emptyWidget: emptyErrorWidget,
      slivers: isNotEmpty(widgetListBuilder)? widgetListBuilder(data) : [
        isEmpty(emptyErrorWidget)? isNotEmpty(builder)? builder(data) : SliverToBoxAdapter(child: Container(),) :SliverToBoxAdapter(child: Container(),),
      ],
      onRefresh: isBusy? null : () async{
        getData();
      },
      onLoad: onLoad,
      controller: refreshController,
    );
  }

  void requestWhenError(){
    setBusy();
    getData();
  }
}
